EchoDot69420

cancelOnQuit not working Log

Oct 29th, 2025
61
0
Never
Not a member of Pastebin yet? Sign Up, it unlocks many cool features!
text 48.35 KB | None | 0 0
  1. [20:28:50] [ServerMain/INFO]: [bootstrap] Running Java 21 (OpenJDK 64-Bit Server VM 21.0.8+9-Ubuntu-0ubuntu124.04.1; Ubuntu null) on Linux 6.8.0-85-generic (amd64)
  2. [20:28:50] [ServerMain/INFO]: [bootstrap] Loading Paper 1.21.5-114-ver/1.21.5@a1b3058 (2025-06-18T10:59:02Z) for Minecraft 1.21.5
  3. [20:28:50] [ServerMain/INFO]: [PluginInitializerManager] Initializing plugins...
  4. [20:28:51] [ServerMain/INFO]: [PluginInitializerManager] Initialized 14 plugins
  5. [20:28:51] [ServerMain/INFO]: [PluginInitializerManager] Bukkit plugins (14):
  6. - AxiomPaper (5.0.1+1.21.5), LibsDisguises (11.0.9), MMOCore (1.13.1-SNAPSHOT), MMOInventory (2.0-SNAPSHOT), MMOItems (6.10.1-SNAPSHOT), MythicCrucible (2.2.0-SNAPSHOT), MythicHUD (1.3.1-SNAPSHOT), MythicLib (1.7.1-SNAPSHOT), MythicMobs (5.10.1-SNAPSHOT-ae8b9c3d), PlaceholderAPI (2.11.6), ProtocolLib (5.4.0), SimpleScore (4.0.1), WorldEdit (7.3.16+cbf4bd5), packetevents (2.10.0)
  7. [20:28:53] [ServerMain/WARN]: resource-pack-id missing, using default of 1a6401bc-1109-3ba0-b0e8-aadf244daa60
  8. [20:28:53] [ServerMain/INFO]: Environment: Environment[sessionHost=https://sessionserver.mojang.com, servicesHost=https://api.minecraftservices.com, name=PROD]
  9. [20:28:53] [ServerMain/INFO]: Loaded 1373 recipes
  10. [20:28:53] [ServerMain/INFO]: Loaded 1484 advancements
  11. [20:28:53] [Server thread/INFO]: Starting minecraft server version 1.21.5
  12. [20:28:53] [Server thread/INFO]: Loading properties
  13. [20:28:54] [Server thread/INFO]: This server is running Paper version 1.21.5-114-ver/1.21.5@a1b3058 (2025-06-18T10:59:02Z) (Implementing API version 1.21.5-R0.1-SNAPSHOT)
  14. [20:28:54] [Server thread/INFO]: [spark] This server bundles the spark profiler. For more information please visit https://docs.papermc.io/paper/profiling
  15. [20:28:54] [Server thread/INFO]: Server Ping Player Sample Count: 12
  16. [20:28:54] [Server thread/INFO]: Using 4 threads for Netty based IO
  17. [20:28:54] [Server thread/INFO]: [MoonriseCommon] Paper is using 5 worker threads, 1 I/O threads
  18. [20:28:54] [Server thread/INFO]: [ChunkTaskScheduler] Chunk system is using population gen parallelism: true
  19. [20:28:54] [Server thread/INFO]: Default game type: SURVIVAL
  20. [20:28:54] [Server thread/INFO]: Generating keypair
  21. [20:28:54] [Server thread/INFO]: Starting Minecraft server on *:25565
  22. [20:28:54] [Server thread/INFO]: Using epoll channel type
  23. [20:28:54] [Server thread/INFO]: Paper: Using libdeflate (Linux x86_64) compression from Velocity.
  24. [20:28:54] [Server thread/INFO]: Paper: Using OpenSSL 3.x.x (Linux x86_64) cipher from Velocity.
  25. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loading 4 libraries... please wait
  26. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-api/4.16.0/adventure-api-4.16.0.jar
  27. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-key/4.16.0/adventure-key-4.16.0.jar
  28. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/examination-api/1.3.0/examination-api-1.3.0.jar
  29. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/examination-string/1.3.0/examination-string-1.3.0.jar
  30. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/org/jetbrains/annotations/24.1.0/annotations-24.1.0.jar
  31. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-platform-bukkit/4.3.2/adventure-platform-bukkit-4.3.2.jar
  32. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-platform-api/4.3.2/adventure-platform-api-4.3.2.jar
  33. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-serializer-bungeecord/4.3.2/adventure-text-serializer-bungeecord-4.3.2.jar
  34. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-serializer-legacy/4.13.1/adventure-text-serializer-legacy-4.13.1.jar
  35. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-nbt/4.13.1/adventure-nbt-4.13.1.jar
  36. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-serializer-gson-legacy-impl/4.13.1/adventure-text-serializer-gson-legacy-impl-4.13.1.jar
  37. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-platform-facet/4.3.2/adventure-platform-facet-4.3.2.jar
  38. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-platform-viaversion/4.3.2/adventure-platform-viaversion-4.3.2.jar
  39. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-minimessage/4.16.0/adventure-text-minimessage-4.16.0.jar
  40. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-serializer-gson/4.16.0/adventure-text-serializer-gson-4.16.0.jar
  41. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-serializer-json/4.16.0/adventure-text-serializer-json-4.16.0.jar
  42. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/option/1.0.0/option-1.0.0.jar
  43. [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/com/google/code/gson/gson/2.8.0/gson-2.8.0.jar
  44. [20:28:54] [Server thread/INFO]: [ProtocolLib] Loading server plugin ProtocolLib v5.4.0
  45. [20:28:55] [Server thread/INFO]: [packetevents] Loading server plugin packetevents v2.10.0
  46. [20:28:55] [Server thread/INFO]: [PlaceholderAPI] Loading server plugin PlaceholderAPI v2.11.6
  47. [20:28:55] [Server thread/INFO]: [LibsDisguises] Loading server plugin LibsDisguises v11.0.9
  48. [20:28:55] [Server thread/INFO]: [MythicMobs] Loading server plugin MythicMobs v5.10.1-SNAPSHOT-ae8b9c3d
  49. [20:28:55] [Server thread/INFO]: [LumineUtils] (io.lumine.mythic.bukkit.utils.) is bound to plugin MythicMobs - io.lumine.mythic.bukkit.MythicBukkit
  50. [20:28:55] [Server thread/INFO]: [MythicMobs] §x§f§f§0§0§0§0M§x§f§f§6§6§0§0y§x§f§f§c§c§0§0t§x§c§b§f§f§0§0h§x§6§5§f§f§0§0i§x§0§0§f§f§0§0c§x§0§0§f§f§6§6 §x§0§0§f§f§c§bE§x§0§0§c§b§f§fn§x§0§0§6§5§f§fa§x§0§0§0§0§f§fb§x§6§6§0§0§f§fl§x§c§c§0§0§f§fe§x§f§f§0§0§c§cd§x§f§f§0§0§6§6!
  51. [20:28:55] [Server thread/INFO]: [MythicLib] Loading server plugin MythicLib v1.7.1-SNAPSHOT
  52. [20:28:55] [Server thread/INFO]: [MythicLib] Plugin file is called 'MythicLib-dist-1.7.1-20251023.125447-44.jar'
  53. [20:28:55] [Server thread/INFO]: [MythicLib] Detected Bukkit Version: v1_21_R4
  54. [20:28:55] [Server thread/INFO]: [MMOCore] Loading server plugin MMOCore v1.13.1-SNAPSHOT
  55. [20:28:55] [Server thread/INFO]: [MMOCore] Plugin file is called 'MMOCore-1.13.1-20251020.220648-27 (1).jar'
  56. [20:28:55] [Server thread/INFO]: [MMOItems] Loading server plugin MMOItems v6.10.1-SNAPSHOT
  57. [20:28:55] [Server thread/INFO]: [MMOItems] Plugin file is called 'MMOItems-6.10.1-20251022.221410-36.jar'
  58. [20:28:55] [Server thread/INFO]: [MMOItems] Hooked onto WorldEdit
  59. [20:28:56] [Server thread/INFO]: [MMOItems Template Modifiers] Preloading template modifiers, please wait..
  60. [20:28:56] [Server thread/INFO]: [MMOItems Item Templates] Preloading item templates, please wait..
  61. [20:28:56] [Server thread/INFO]: [MMOItems] Hooked onto MythicMobs
  62. [20:28:56] [Server thread/INFO]: [MythicCrucible] Loading server plugin MythicCrucible v2.2.0-SNAPSHOT
  63. [20:28:56] [Server thread/INFO]: [MythicHUD] Loading server plugin MythicHUD v1.3.1-SNAPSHOT
  64. [20:28:56] [Server thread/INFO]: [AxiomPaper] Loading server plugin AxiomPaper v5.0.1+1.21.5
  65. [20:28:56] [Server thread/INFO]: [SimpleScore] Loading server plugin SimpleScore v4.0.1
  66. [20:28:56] [Server thread/INFO]: [WorldEdit] Loading server plugin WorldEdit v7.3.16+cbf4bd5
  67. [20:28:56] [Server thread/INFO]: Got request to register class com.sk89q.worldedit.bukkit.BukkitServerInterface with WorldEdit [com.sk89q.worldedit.extension.platform.PlatformManager@791276df]
  68. [20:28:56] [Server thread/INFO]: [MMOInventory] Loading server plugin MMOInventory v2.0-SNAPSHOT
  69. [20:28:56] [Server thread/INFO]: [MMOInventory] Plugin file is called 'MMOInventory-2.0-20251023.122947-14.jar'
  70. [20:28:56] [Server thread/INFO]: Server permissions file permissions.yml is empty, ignoring it
  71. [20:28:56] [Server thread/INFO]: [ProtocolLib] Enabling ProtocolLib v5.4.0
  72. [20:28:56] [Server thread/INFO]: [WorldEdit] Enabling WorldEdit v7.3.16+cbf4bd5
  73. [20:28:56] [Server thread/INFO]: Registering commands with com.sk89q.worldedit.bukkit.BukkitServerInterface
  74. [20:28:56] [Server thread/INFO]: WEPIF: Using the Bukkit Permissions API.
  75. [20:28:56] [Server thread/INFO]: Using com.sk89q.worldedit.bukkit.adapter.impl.v1_21_5.PaperweightAdapter as the Bukkit adapter
  76. [20:28:56] [Server thread/WARN]: **** SERVER IS RUNNING IN OFFLINE/INSECURE MODE!
  77. [20:28:56] [Server thread/WARN]: The server will make no attempt to authenticate usernames. Beware.
  78. [20:28:56] [Server thread/WARN]: While this makes the game possible to play without internet access, it also opens up the ability for hackers to connect with any username they choose.
  79. [20:28:56] [Server thread/WARN]: To change this, set "online-mode" to "true" in the server.properties file.
  80. [20:28:56] [Server thread/INFO]: Preparing level "world"
  81. [20:28:57] [Server thread/INFO]: Preparing start region for dimension minecraft:overworld
  82. [20:28:57] [Server thread/INFO]: Preparing spawn area: 0%
  83. [20:28:57] [Server thread/INFO]: Time elapsed: 383 ms
  84. [20:28:57] [Server thread/INFO]: Preparing start region for dimension minecraft:the_nether
  85. [20:28:57] [Server thread/INFO]: Preparing spawn area: 0%
  86. [20:28:57] [Server thread/INFO]: Time elapsed: 40 ms
  87. [20:28:57] [Server thread/INFO]: Preparing start region for dimension minecraft:the_end
  88. [20:28:57] [Server thread/INFO]: Preparing spawn area: 0%
  89. [20:28:57] [Server thread/INFO]: Time elapsed: 28 ms
  90. [20:28:57] [Server thread/INFO]: [packetevents] Enabling packetevents v2.10.0
  91. [20:28:57] [packetevents-update-check-thread/INFO]: [packetevents] Checking for updates, please wait...
  92. [20:28:57] [Server thread/INFO]: [PlaceholderAPI] Enabling PlaceholderAPI v2.11.6
  93. [20:28:57] [Server thread/INFO]: [PlaceholderAPI] Fetching available expansion information...
  94. [20:28:57] [Server thread/INFO]: [LibsDisguises] Enabling LibsDisguises v11.0.9
  95. [20:28:57] [Server thread/INFO]: [LibsDisguises] File Name: LibsDisguises-11.0.9-Free.jar
  96. [20:28:57] [Server thread/INFO]: [LibsDisguises] Discovered nms version: (Package: {Not package relocated}) (LD: v1_21_R4) (MC: 1.21.5)
  97. [20:28:57] [Server thread/INFO]: [LibsDisguises] Jenkins Build: #1637
  98. [20:28:57] [Server thread/INFO]: [LibsDisguises] Build Date: 11/09/2025 04:26
  99. [20:28:57] [Server thread/INFO]: [LibsDisguises] If you own the plugin, place the premium jar downloaded from https://www.spigotmc.org/resources/libs-disguises.32453/ in plugins/LibsDisguises/
  100. [20:28:57] [Server thread/INFO]: [LibsDisguises] You are running the free version, commands limited to non-players and operators. (Console, Command Blocks, Admins)
  101. [20:28:57] [Server thread/INFO]: [LibsDisguises] Config 'TallSelfDisguises' is set to 'SCALED', LD will scale down (when possible) oversized disguises from self disguise. https://www.spigotmc.org/wiki/lib-s-disguises-faq/#tall-disguises-self-disguises
  102. [20:28:57] [packetevents-update-check-thread/INFO]: [packetevents] You are running the latest release of PacketEvents. Your build: (2.10.0)
  103. [20:28:58] [Server thread/INFO]: [com.github.retrooper.packetevents.PacketEventsAPI] Loading block mappings for V_1_21_5/18...
  104. [20:28:58] [Server thread/INFO]: [com.github.retrooper.packetevents.PacketEventsAPI] Finished loading block mappings for V_1_21_5/18 in 124.901551ms
  105. [20:28:58] [Yggdrasil Key Fetcher/ERROR]: Failed to request yggdrasil public key
  106. com.mojang.authlib.exceptions.MinecraftClientException: Failed to read from https://api.minecraftservices.com/publickeys due to Read timed out
  107. at com.mojang.authlib.minecraft.client.MinecraftClient.readInputStream(MinecraftClient.java:111) ~[authlib-6.0.58.jar:?]
  108. at com.mojang.authlib.minecraft.client.MinecraftClient.get(MinecraftClient.java:56) ~[authlib-6.0.58.jar:?]
  109. at com.mojang.authlib.yggdrasil.YggdrasilServicesKeyInfo.fetch(YggdrasilServicesKeyInfo.java:114) ~[authlib-6.0.58.jar:?]
  110. at com.mojang.authlib.yggdrasil.YggdrasilServicesKeyInfo$1.run(YggdrasilServicesKeyInfo.java:89) ~[authlib-6.0.58.jar:?]
  111. at java.base/java.util.concurrent.Executors$RunnableAdapter.call(Executors.java:572) ~[?:?]
  112. at java.base/java.util.concurrent.FutureTask.run(FutureTask.java:317) ~[?:?]
  113. at java.base/java.util.concurrent.ScheduledThreadPoolExecutor$ScheduledFutureTask.run(ScheduledThreadPoolExecutor.java:304) ~[?:?]
  114. at java.base/java.util.concurrent.ThreadPoolExecutor.runWorker(ThreadPoolExecutor.java:1144) ~[?:?]
  115. at java.base/java.util.concurrent.ThreadPoolExecutor$Worker.run(ThreadPoolExecutor.java:642) ~[?:?]
  116. at java.base/java.lang.Thread.run(Thread.java:1583) ~[?:?]
  117. Caused by: java.net.SocketTimeoutException: Read timed out
  118. at java.base/sun.nio.ch.NioSocketImpl.timedRead(NioSocketImpl.java:278) ~[?:?]
  119. at java.base/sun.nio.ch.NioSocketImpl.implRead(NioSocketImpl.java:304) ~[?:?]
  120. at java.base/sun.nio.ch.NioSocketImpl.read(NioSocketImpl.java:346) ~[?:?]
  121. at java.base/sun.nio.ch.NioSocketImpl$1.read(NioSocketImpl.java:796) ~[?:?]
  122. at java.base/java.net.Socket$SocketInputStream.read(Socket.java:1099) ~[?:?]
  123. at java.base/sun.security.ssl.SSLSocketInputRecord.read(SSLSocketInputRecord.java:489) ~[?:?]
  124. at java.base/sun.security.ssl.SSLSocketInputRecord.readHeader(SSLSocketInputRecord.java:483) ~[?:?]
  125. at java.base/sun.security.ssl.SSLSocketInputRecord.decode(SSLSocketInputRecord.java:160) ~[?:?]
  126. at java.base/sun.security.ssl.SSLTransport.decode(SSLTransport.java:111) ~[?:?]
  127. at java.base/sun.security.ssl.SSLSocketImpl.decode(SSLSocketImpl.java:1506) ~[?:?]
  128. at java.base/sun.security.ssl.SSLSocketImpl.readHandshakeRecord(SSLSocketImpl.java:1421) ~[?:?]
  129. at java.base/sun.security.ssl.SSLSocketImpl.startHandshake(SSLSocketImpl.java:455) ~[?:?]
  130. at java.base/sun.security.ssl.SSLSocketImpl.startHandshake(SSLSocketImpl.java:426) ~[?:?]
  131. at java.base/sun.net.www.protocol.https.HttpsClient.afterConnect(HttpsClient.java:586) ~[?:?]
  132. at java.base/sun.net.www.protocol.https.AbstractDelegateHttpsURLConnection.connect(AbstractDelegateHttpsURLConnection.java:187) ~[?:?]
  133. at java.base/sun.net.www.protocol.http.HttpURLConnection.getInputStream0(HttpURLConnection.java:1691) ~[?:?]
  134. at java.base/sun.net.www.protocol.http.HttpURLConnection.getInputStream(HttpURLConnection.java:1615) ~[?:?]
  135. at java.base/java.net.HttpURLConnection.getResponseCode(HttpURLConnection.java:531) ~[?:?]
  136. at java.base/sun.net.www.protocol.https.HttpsURLConnectionImpl.getResponseCode(HttpsURLConnectionImpl.java:307) ~[?:?]
  137. at com.mojang.authlib.minecraft.client.MinecraftClient.readInputStream(MinecraftClient.java:82) ~[authlib-6.0.58.jar:?]
  138. ... 9 more
  139. [20:28:58] [Server thread/INFO]: [LibsDisguises] Config is up to date!
  140. [20:28:58] [Server thread/INFO]: [PlaceholderAPI] Successfully registered internal expansion: libsdisguises [1.0.0]
  141. [20:28:58] [Server thread/INFO]: [LibsDisguises] PlaceholderAPI support enabled
  142. [20:28:58] [Server thread/INFO]: [MythicMobs] Enabling MythicMobs v5.10.1-SNAPSHOT-ae8b9c3d
  143. [20:28:58] [Server thread/INFO]: [MythicMobs] Loading MythicMobs for Paper (MC: 1.21.5)...
  144. [20:28:58] [Server thread/INFO]: [MythicMobs] The server is running Paper; enabled Paper exclusive functionality
  145. [20:28:59] [Server thread/INFO]: [MythicMobs] Mythic LibsDisguises Support has been enabled!
  146. [20:28:59] [Server thread/INFO]: [MythicMobs] Mythic MMOItems Support has been enabled!
  147. [20:28:59] [Server thread/INFO]: [PlaceholderAPI] Successfully registered internal expansion: mythic [5.0.0]
  148. [20:28:59] [Server thread/INFO]: [MythicMobs] Mythic PlaceholderAPI Support has been enabled!
  149. [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Packs...
  150. [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Items...
  151. [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Item Groups...
  152. [20:29:01] [Server thread/INFO]: [MythicMobs] All items loaded after 21ms!
  153. [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Skills...
  154. [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Drop Tables...
  155. [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Random Spawns...
  156. [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Spawn Blocks...
  157. [20:29:01] [Server thread/INFO]: [MythicMobs] Second passes loaded after 11ms!
  158. [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 8 mobs.
  159. [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 3 vanilla mob overrides.
  160. [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 0 mob stacks.
  161. [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 85 skills.
  162. [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 0 random spawns.
  163. [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 3 mythic items.
  164. [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 2 drop tables.
  165. [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 0 mob spawners.
  166. [20:29:01] [Server thread/INFO]: [MythicMobs] MythicMobs configuration file loaded successfully.
  167. [20:29:01] [Server thread/INFO]: [MythicMobs] Started up bStats Metrics
  168. [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ MythicMobs Premium v5.10.1 ( build ae8b9c3d ) has been successfully loaded!
  169. [20:29:01] [Server thread/INFO]: [MythicLib] Enabling MythicLib v1.7.1-SNAPSHOT
  170. [20:29:01] [Server thread/INFO]: [MythicLib] Hooked onto TextDisplays (holograms)
  171. [20:29:01] [Server thread/INFO]: [MythicMobs] MMO Plugin Support has been enabled!
  172. [20:29:01] [Server thread/INFO]: [MythicLib] Hooked onto MythicMobs
  173. [20:29:01] [Server thread/INFO]: [MythicLib] Hooked onto ProtocolLib
  174. [20:29:01] [Server thread/INFO]: [PlaceholderAPI] Successfully registered internal expansion: mythiclib [1.7.1-SNAPSHOT]
  175. [20:29:01] [Server thread/INFO]: [MythicLib] Hooked onto PlaceholderAPI
  176. [20:29:01] [Server thread/INFO]: Environment: Environment[sessionHost=https://sessionserver.mojang.com, servicesHost=https://api.minecraftservices.com, name=PROD]
  177. [20:29:01] [Server thread/INFO]: [MMOCore] Enabling MMOCore v1.13.1-SNAPSHOT
  178. [20:29:01] [Server thread/INFO]: [PlaceholderAPI] Successfully registered internal expansion: mmocore [1.13.1-SNAPSHOT]
  179. [20:29:01] [Server thread/INFO]: [MMOCore] Hooked onto PlaceholderAPI
  180. [20:29:01] [Server thread/INFO]: [MMOCore] Hooked onto MythicMobs
  181. [20:29:01] [Server thread/WARN]: [MMOCore] Could not load language entry 'gold-pouch-ui-name': Entry not found
  182. [20:29:01] [Server thread/WARN]: [MMOCore] Could not load message 'guild-no-pending-invite': Translation not found
  183. [20:29:01] [Server thread/WARN]: [MMOCore] Could not load message 'friend-no-pending-invite': Translation not found
  184. [20:29:01] [Server thread/WARN]: [MMOCore] Could not load message 'party-no-pending-invite': Translation not found
  185. [20:29:01] [Server thread/WARN]: [MMOCore] Could not load message 'no-class-skill-tree': Translation not found
  186. [20:29:01] [Server thread/WARN]: [MMOCore] Could not load custom mining condition 'region{name="example_region,example_region2,__global__"}': Could not match any condition to 'region' in database
  187. [20:29:01] [Server thread/WARN]: [MMOCore] Could not load custom mining condition 'region{name="example_region,example_region2,__global__"}': Could not match any condition to 'region' in database
  188. [20:29:01] [Server thread/WARN]: [MMOCore] Could not load condition 'region{name="swamp,second-region"}' from fishing drop table 'overriding-drop-table': Could not match any condition to 'region' in database
  189. [20:29:01] [Server thread/WARN]: [MMOCore] Could not load loot chest region 'sample-region' from file 'default_loot_chests.yml': Could not find world 'world_name_here'
  190. [20:29:01] [Server thread/INFO]: [MMOCore] Hooked parties onto MMOCore
  191. [20:29:01] [Server thread/INFO]: [MMOCore] Hooked guilds onto MMOCore
  192. [20:29:01] [Server thread/INFO]: [MMOItems] Enabling MMOItems v6.10.1-SNAPSHOT
  193. [20:29:01] [Server thread/INFO]: [MMOItems] Hooked onto MythicMobs
  194. [20:29:01] [Server thread/INFO]: [MMOItems] Hooked onto MMOInventory
  195. [20:29:01] [Server thread/INFO]: [MMOItems] Hooked onto MMOCore
  196. [20:29:01] [Server thread/INFO]: [MMOItems] Now using MMOCore as RPG core plugin
  197. [20:29:01] [Server thread/INFO]: [MMOItems Template Modifiers] Loading template modifiers, please wait..
  198. [20:29:02] [Server thread/INFO]: [MMOItems Item Templates] Loading item templates, please wait...
  199. [20:29:02] [Server thread/INFO]: [MMOItems Item Templates (WAND)] Could not post-load item template 'OAK_WAND': Could not find stat with ID 'CUSTOM_ABILITYHASTE'
  200. [20:29:02] [Server thread/INFO]: [MMOItems Item Templates (WAND)] Could not post-load item template 'SIMPLEWAND': Could not find stat with ID 'CUSTOM_ABILITYHASTE'
  201. [20:29:02] [Server thread/INFO]: [MMOItems] Loading crafting stations, please wait..
  202. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'arcane-helmet' from crafting station 'arcane-forge': Could not find a template with ID 'ARCANE_HELM'
  203. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'arcane-chestplate' from crafting station 'arcane-forge': Could not find a template with ID 'ARCANE_CHESTPLATE'
  204. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'arcane-leggings' from crafting station 'arcane-forge': Could not find a template with ID 'ARCANE_LEGGINGS'
  205. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'arcane-boots' from crafting station 'arcane-forge': Could not find a template with ID 'ARCANE_BOOTS'
  206. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'cursed-wither-skull' from crafting station 'mythical-forge': Could not find a template with ID 'CURSED_WITHER_SKULL'
  207. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'dead-pharaoh-helmet' from crafting station 'mythical-forge': Could not find a template with ID 'DEAD_PHARAOH_HELMET'
  208. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'mossy-skeleton-skull' from crafting station 'mythical-forge': Could not find a template with ID 'MOSSY_SKELETON_SKULL'
  209. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'steel-helmet' from crafting station 'steel-crafting-station': Could not find a template with ID 'STEEL_HELMET'
  210. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'steel-chestplate' from crafting station 'steel-crafting-station': Could not find a template with ID 'STEEL_CHESTPLATE'
  211. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'steel-leggings' from crafting station 'steel-crafting-station': Could not find a template with ID 'STEEL_LEGGINGS'
  212. [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'steel-boots' from crafting station 'steel-crafting-station': Could not find a template with ID 'STEEL_BOOTS'
  213. [20:29:02] [Server thread/INFO]: [MMOItems] Hooked onto MMOInventory
  214. [20:29:02] [Server thread/INFO]: [PlaceholderAPI] Successfully registered internal expansion: mmoitems [6.10.1-SNAPSHOT]
  215. [20:29:02] [Server thread/INFO]: [MMOItems] Hooked onto PlaceholderAPI
  216. [20:29:02] [Server thread/INFO]: [MMOItems] Loading recipes, please wait...
  217. [20:29:02] [Server thread/INFO]: [MythicCrucible] Enabling MythicCrucible v2.2.0-SNAPSHOT
  218. [20:29:02] [Server thread/INFO]: [MythicMobs] §6------------------------------------------------
  219. [20:29:02] [Server thread/INFO]: [MythicMobs] §b+ Loading MythicCrucible for Bukkit
  220. [20:29:02] [Server thread/INFO]: [MythicMobs] §6------------------------------------------------
  221. [20:29:02] [Server thread/INFO]: [MythicMobs] Registering Durability Listener
  222. [20:29:07] [Server thread/INFO]: [MythicMobs] Started up bStats Metrics
  223. [20:29:07] [Server thread/INFO]: [MythicMobs] MythicCrucible Support has been enabled!
  224. [20:29:07] [Server thread/INFO]: [MythicMobs] MythicCrucible WorldEdit support enabled!
  225. [20:29:07] [Server thread/INFO]: [MythicMobs] Attached traits to items.
  226. [20:29:07] [Server thread/INFO]: [MythicMobs] Loaded 3 items.
  227. [20:29:07] [Server thread/INFO]: [MythicMobs] Loaded 2 drop tables.
  228. [20:29:07] [Server thread/INFO]: [MythicMobs] ✓ MythicCrucible v2.2.0 has been successfully loaded!
  229. [20:29:07] [Server thread/INFO]: [MythicHUD] Enabling MythicHUD v1.3.1-SNAPSHOT
  230. [20:29:07] [Server thread/INFO]: [MythicHUD] Mythic support detected.
  231. [20:29:07] [Server thread/INFO]: [MythicHUD] PlaceholderAPI parser has been registered.
  232. [20:29:07] [Server thread/INFO]: [MythicHUD] Generating resource pack for all versions
  233. [20:29:07] [Server thread/INFO]: [MythicHUD] [ACF] Enabled Asynchronous Tab Completion Support!
  234. [20:29:07] [Server thread/INFO]: [AxiomPaper] Enabling AxiomPaper v5.0.1+1.21.5
  235. [20:29:07] [Server thread/INFO]: [SimpleScore] Enabling SimpleScore v4.0.1
  236. [20:29:08] [Server thread/INFO]: [MMOInventory] Enabling MMOInventory v2.0-SNAPSHOT
  237. [20:29:08] [Server thread/WARN]: [MMOInventory] Could not load message 'elytra-equip': Translation not found
  238. [20:29:08] [Server thread/WARN]: [MMOInventory] Could not load message 'elytra-unequip': Translation not found
  239. [20:29:08] [Server thread/WARN]: [MMOInventory] Could not load message 'inspect': Translation not found
  240. [20:29:08] [Server thread/INFO]: [spark] Starting background profiler...
  241. [20:29:08] [Server thread/INFO]: [PlaceholderAPI] Placeholder expansion registration initializing...
  242. [20:29:08] [Server thread/INFO]: Done preparing level "world" (11.479s)
  243. [20:29:08] [Server thread/INFO]: Running delayed init tasks
  244. [20:29:08] [Server thread/WARN]: [MythicMobs] ✗ Configuration Error in Mechanic CustomMechanic:NULL
  245. [20:29:08] [Server thread/WARN]: [MythicMobs] --| Skill: MeechLavaSwimSpeedTick | File: /home/ProjectCrimson/server/plugins/MythicMobs/skills/learningFolders/MeechSkills.yml
  246. [20:29:08] [Server thread/WARN]: [MythicMobs] --| Error Message: Failed to load custom mechanic HASAURA
  247. [20:29:08] [Server thread/WARN]: [MythicMobs] --| Mechanic Line: hasAura{LavaFlight}
  248. [20:29:08] [Server thread/INFO]: Done (18.039s)! For help, type "help"
  249. [20:29:08] [Craft Scheduler Thread - 6 - MMOInventory/INFO]: [MMOInventory] A new build is available: 1.9 (you are running 2.0-SNAPSHOT)
  250. [20:29:08] [Craft Scheduler Thread - 6 - MMOInventory/INFO]: [MMOInventory] Download it here: https://www.spigotmc.org/resources/99445/
  251. [20:29:08] [Server thread/INFO]: [PlaceholderAPI] Successfully registered external expansion: PAPIFormula [1.0.0]
  252. [20:29:08] [Server thread/INFO]: [PlaceholderAPI] Successfully registered external expansion: math [2.0.2]
  253. [20:29:08] [Server thread/INFO]: 2 placeholder hook(s) registered!
  254. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Starting Pack Generator...
  255. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Processing MythicHUD Pack...
  256. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generating Custom Blocks...
  257. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generating Items...
  258. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Assigning Legacy CMD Materials...
  259. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generating Legacy Definitions...
  260. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generating Sounds...
  261. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Linking Custom Blocks...
  262. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generating Atlas...
  263. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Zipping Pack...
  264. [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generation Completed in 68ms
  265. [20:29:21] [User Authenticator #0/INFO]: UUID of player Sukichan is fcd961d5-3a14-3910-97ee-06060bf286b8
  266. [20:29:21] [Server thread/INFO]: Sukichan joined the game
  267. [20:29:21] [Server thread/INFO]: Sukichan[/192.168.1.239:52769] logged in with entity id 287 at ([world]102.35984620592187, 114.0, -53.783073492140915)
  268. [20:29:31] [Server thread/INFO]: Sukichan issued server command: /mm debug
  269. [20:29:35] [Server thread/INFO]: Sukichan issued server command: /mm debug 4
  270. [20:29:38] [Server thread/INFO]: Sukichan issued server command: /mm test cast applyTest
  271. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- ! Skill usable!
  272. [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic skill:applyDebuff{aura=debuff3;duration=2000;interval=10;onTick=[]} @self
  273. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- + SkillMechanic metaskill is usable!
  274. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Executing SkillMechanic metaskill with power 1 (line: skill:applyDebuff{aura=debuff3;duration=2000;interval=10;onTick=[]} @self)
  275. [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : EntityTargeter found 1 targets
  276. [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Applying entity target filters
  277. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Returning 1 targets
  278. [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  279. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- ! Skill usable!
  280. [20:29:38] [Server thread/INFO]: [MythicMobs] +--- Running Skill applyDebuff Async from MetaSkillMechanic
  281. [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic message{m="Applying<&sp><skill.aura><&sp>to<&sp><target.name>"} @caster
  282. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- + SkillMechanic message is usable!
  283. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Executing SkillMechanic message with power 1 (line: message{m="Applying<&sp><skill.aura><&sp>to<&sp><target.name>"} @caster)
  284. [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : EntityTargeter found 1 targets
  285. [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Applying entity target filters
  286. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Returning 1 targets
  287. [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic accepts multiple types...
  288. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Mechanic is ITargetedEntitySkill
  289. [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic io.lumine.mythic.core.skills.mechanics.MessageMechanic is an ENTITY skill. Executing...
  290. [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic setVariable{name=target.debuffs;type=LIST;value=""} ?!variableIsSet{name=target.debuffs}
  291. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- ! SkillMechanic not usable: Condition variableIsSet failed
  292. [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic addVariable{name=target.debuffs;value=<skill.aura>}
  293. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- + SkillMechanic variableAdd is usable!
  294. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Executing SkillMechanic variableAdd with power 1 (line: addVariable{name=target.debuffs;value=<skill.aura>})
  295. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Mechanic is ITargetedEntitySkill
  296. [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic io.lumine.mythic.core.skills.mechanics.VariableAddMechanic is an ENTITY skill. Executing...
  297. [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic aura{aura=<skill.aura>;interval=<skill.interval>;d=<skill.duration>;<&csp>ontickskill=[<&da><&csp>vskill{skill=<skill.onTick>}];onendskill=[<&csp><&da><&csp>delay<&csp>1<&csp><&da><&csp>skill:removeDebuff{value=<skill.aura>}];<&csp>showbartimer=true;<&csp>coq=true<&csp>}
  298. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- + SkillMechanic aura is usable!
  299. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Executing SkillMechanic aura with power 1 (line: aura{aura=<skill.aura>;interval=<skill.interval>;d=<skill.duration>;<&csp>ontickskill=[<&da><&csp>vskill{skill=<skill.onTick>}];onendskill=[<&csp><&da><&csp>delay<&csp>1<&csp><&da><&csp>skill:removeDebuff{value=<skill.aura>}];<&csp>showbartimer=true;<&csp>coq=true<&csp>})
  300. [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic accepts multiple types...
  301. [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Mechanic is ITargetedEntitySkill
  302. [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic io.lumine.mythic.core.skills.mechanics.AuraMechanic is an ENTITY skill. Executing...
  303. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  304. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
  305. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
  306. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
  307. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  308. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  309. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
  310. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  311. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
  312. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
  313. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
  314. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  315. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  316. [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
  317. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  318. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
  319. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
  320. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
  321. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  322. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  323. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
  324. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  325. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
  326. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
  327. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
  328. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  329. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  330. [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
  331. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  332. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
  333. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
  334. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
  335. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  336. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  337. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
  338. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  339. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
  340. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
  341. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
  342. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  343. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  344. [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
  345. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  346. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
  347. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
  348. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
  349. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  350. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  351. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
  352. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  353. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
  354. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
  355. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
  356. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  357. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  358. [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
  359. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  360. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
  361. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
  362. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
  363. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  364. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  365. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
  366. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  367. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
  368. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
  369. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
  370. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
  371. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
  372. [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
  373. [20:29:42] [Server thread/INFO]: Sukichan lost connection: Disconnected
  374. [20:29:42] [Server thread/INFO]: [MythicMobs] |----- ! Skill usable!
  375. [20:29:42] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic delay 1
  376. [20:29:42] [Server thread/INFO]: [MythicMobs] [i] Updating Armor
  377. [20:29:42] [Server thread/INFO]: Sukichan left the game
  378. [20:29:54] [User Authenticator #0/INFO]: UUID of player Sukichan is fcd961d5-3a14-3910-97ee-06060bf286b8
  379. [20:29:54] [Server thread/INFO]: [MythicMobs] [i] CrucibleProfile not loaded yet for Sukichan
  380. [20:29:54] [Server thread/INFO]: Sukichan joined the game
  381. [20:29:54] [Server thread/INFO]: Sukichan[/192.168.1.239:52792] logged in with entity id 364 at ([world]102.35984620592187, 114.0, -53.783073492140915)
  382. [20:29:54] [Server thread/INFO]: [MythicMobs] [i] Loaded profile for Sukichan
  383. [20:29:54] [Server thread/INFO]: [MythicMobs] [i] Parsing Weapon for Sukichan
  384. [20:29:55] [Server thread/INFO]: [MythicMobs] [i] Updating Armor (Delayed)
  385. [20:29:55] [Server thread/INFO]: [MythicMobs] [i] Updating Armor
  386. [20:30:02] [Server thread/INFO]: [MythicMobs] [i] Calling MythicMobSpawnEvent for SkeletalKnight (level: 2.0)
  387. [20:30:03] [Server thread/INFO]: [MythicMobs] +--- Generating LootBag
  388. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item IRON_HELMET HEAD amount 1
  389. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: IRON_HELMET HEAD
  390. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item IRON_CHESTPLATE CHEST amount 1
  391. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: IRON_CHESTPLATE CHEST
  392. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item IRON_LEGGINGS LEGS amount 1
  393. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: IRON_LEGGINGS LEGS
  394. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item IRON_BOOTS FEET amount 1
  395. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: IRON_BOOTS FEET
  396. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item IRON_SWORD HAND amount 1
  397. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: IRON_SWORD HAND
  398. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item SHIELD OFFHAND amount 1
  399. [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: SHIELD OFFHAND
  400. [20:30:12] [Server thread/INFO]: Sukichan issued server command: /stop
  401. [20:30:12] [Server thread/INFO]: [Sukichan: Stopping the server]
  402. [20:30:12] [Server thread/INFO]: Stopping server
  403. [20:30:12] [Server thread/INFO]: [MMOInventory] Disabling MMOInventory v2.0-SNAPSHOT
  404. [20:30:12] [Server thread/INFO]: [WorldEdit] Disabling WorldEdit v7.3.16+cbf4bd5
  405. [20:30:12] [Server thread/INFO]: Unregistering com.sk89q.worldedit.bukkit.BukkitServerInterface from WorldEdit
  406. [20:30:12] [Server thread/INFO]: [SimpleScore] Disabling SimpleScore v4.0.1
  407. [20:30:12] [Server thread/INFO]: [AxiomPaper] Disabling AxiomPaper v5.0.1+1.21.5
  408. [20:30:12] [Server thread/INFO]: [MythicHUD] Disabling MythicHUD v1.3.1-SNAPSHOT
  409. [20:30:12] [Server thread/INFO]: [MythicCrucible] Disabling MythicCrucible v2.2.0-SNAPSHOT
  410. [20:30:12] [Server thread/INFO]: [MMOItems] Disabling MMOItems v6.10.1-SNAPSHOT
  411. [20:30:12] [Server thread/INFO]: [MMOCore] Disabling MMOCore v1.13.1-SNAPSHOT
  412. [20:30:12] [Server thread/INFO]: [PlaceholderAPI] Unregistered placeholder expansion PAPIFormula
  413. [20:30:12] [Server thread/INFO]: [PlaceholderAPI] Reason: required plugin MMOCore was disabled.
  414. [20:30:13] [Server thread/INFO]: [MythicLib] Disabling MythicLib v1.7.1-SNAPSHOT
  415. [20:30:13] [Server thread/INFO]: [MythicMobs] Disabling MythicMobs v5.10.1-SNAPSHOT-ae8b9c3d
  416. [20:30:13] [Server thread/INFO]: [MythicMobs] ------------------------------------------------------------
  417. [20:30:13] [Server thread/INFO]: [MythicMobs] -
  418. [20:30:13] [Server thread/INFO]: [MythicMobs] - Unloading Mythic...
  419. [20:30:13] [Server thread/INFO]: [MythicMobs] -
  420. [20:30:13] [Server thread/INFO]: [MythicMobs] ------------------------------------------------------------
  421. [20:30:13] [Server thread/INFO]: [MythicMobs] - Spawners saved and unloaded...
  422. [20:30:13] [Server thread/INFO]: [MythicMobs] +--- Running Mechanics for ActiveMob SkeletalKnight (uuid: e55d4346-6151-4bfe-9db0-a8e03c860cfd)
  423. [20:30:13] [Server thread/INFO]: [MythicMobs] - Mobs saved and unloaded...
  424. [20:30:13] [Server thread/INFO]: [MythicMobs] Saving plugin data...
  425. [20:30:13] [Server thread/INFO]: [MythicMobs] ✓Saving Finished
  426. [20:30:13] [Server thread/INFO]: [MythicMobs] - Variables saved...
  427. [20:30:13] [Server thread/INFO]: [MythicMobs] - All active settings have been saved!
  428. [20:30:13] [Server thread/INFO]: [MythicMobs] - Mythic has been unloaded!
  429. [20:30:13] [Server thread/INFO]: [MythicMobs] ------------------------------------------------------------
  430. [20:30:13] [Server thread/INFO]: [MythicMobs] Saving plugin data...
  431. [20:30:13] [Server thread/INFO]: [MythicMobs] ✓Saving Finished
  432. [20:30:13] [Server thread/INFO]: [LibsDisguises] Disabling LibsDisguises v11.0.9
  433. [20:30:13] [Server thread/INFO]: [PlaceholderAPI] Disabling PlaceholderAPI v2.11.6
  434. [20:30:13] [Server thread/INFO]: [packetevents] Disabling packetevents v2.10.0
  435. [20:30:13] [Server thread/INFO]: [ProtocolLib] Disabling ProtocolLib v5.4.0
  436. [20:30:13] [Server thread/INFO]: Saving players
  437. [20:30:13] [Server thread/INFO]: Sukichan lost connection: Server closed
  438. [20:30:13] [Server thread/INFO]: Sukichan left the game
  439. [20:30:13] [Server thread/INFO]: Saving worlds
  440. [20:30:13] [Server thread/INFO]: Saving chunks for level 'ServerLevel[world]'/minecraft:overworld
  441. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk system to halt for world 'world'
  442. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted chunk system for world 'world'
  443. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saving all chunkholders for world 'world'
  444. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saved 625 block chunks, 625 entity chunks, 0 poi chunks in world 'world' in 0.23s
  445. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk I/O to halt for world 'world'
  446. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted I/O scheduler for world 'world'
  447. [20:30:13] [Server thread/INFO]: Saving chunks for level 'ServerLevel[world_nether]'/minecraft:the_nether
  448. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk system to halt for world 'world_nether'
  449. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted chunk system for world 'world_nether'
  450. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saving all chunkholders for world 'world_nether'
  451. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saved 49 block chunks, 49 entity chunks, 0 poi chunks in world 'world_nether' in 0.05s
  452. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk I/O to halt for world 'world_nether'
  453. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted I/O scheduler for world 'world_nether'
  454. [20:30:13] [Server thread/INFO]: Saving chunks for level 'ServerLevel[world_the_end]'/minecraft:the_end
  455. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk system to halt for world 'world_the_end'
  456. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted chunk system for world 'world_the_end'
  457. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saving all chunkholders for world 'world_the_end'
  458. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saved 49 block chunks, 49 entity chunks, 0 poi chunks in world 'world_the_end' in 0.01s
  459. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk I/O to halt for world 'world_the_end'
  460. [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted I/O scheduler for world 'world_the_end'
  461. [20:30:13] [Server thread/INFO]: ThreadedAnvilChunkStorage (world): All chunks are saved
  462. [20:30:13] [Server thread/INFO]: ThreadedAnvilChunkStorage (DIM-1): All chunks are saved
  463. [20:30:13] [Server thread/INFO]: ThreadedAnvilChunkStorage (DIM1): All chunks are saved
  464. [20:30:13] [Server thread/INFO]: ThreadedAnvilChunkStorage: All dimensions are saved
  465. [20:30:13] [Server thread/INFO]: Waiting for all RegionFile I/O tasks to complete...
  466. [20:30:13] [Server thread/INFO]: All RegionFile I/O tasks to complete
  467. [20:30:13] [Server thread/INFO]: [MoonriseCommon] Awaiting termination of worker pool for up to 60s...
  468. [20:30:13] [Server thread/INFO]: [MoonriseCommon] Awaiting termination of I/O pool for up to 60s...
  469.  
Add Comment
Please, Sign In to add comment